==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/ka_GE.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "პაროლი %s ნიშნის მქონე მაინც უნდა იყოს",
    "Password needs to contain at least one lower and one upper case character." : "პაროლი საჭიროებს ერთ დიდ და ერთ პატარა ასოს მაინც.",
    "Password needs to contain at least one numeric character." : "პაროლი უნდა მოიცავდეს ერთ ციფრს მაინც.",
    "Password needs to contain at least one special character." : "პაროლი უნდა მოიცავდეს ერთ სპეციალურ ნიშანს მაინც.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "პაროლი ერთ-ერთია 1000000 ყველაზე ჩვეულებრივებიდან. გთხოვთ გახადოთ ის უნიკალური.",
    "Password policy" : "პაროლის პოლიტიკა",
    "Minimal length" : "მინ. სიგრძე",
    "Forbid common passwords" : "აკრძალეთ ერთნაირი პაროლები",
    "Enforce upper and lower case characters" : "შემოიღეთ დიდი და პატარა ასოები",
    "Enforce numeric characters" : "შემოიღეთ ნუმერიკული ნიშნები",
    "Enforce special characters" : "შემოიღეთ სპეციალური ნიშნები",
    "Password need to be at least %s characters long" : "პაროლი უნდა იყოს %sნიშნის მქონე მაინც",
    "Password need to contain at least one lower case character and one upper case character." : "პაროლი საჭიროებს ერთ დიდ და ერთ პატარა ასოს მაინც.",
    "Password need to contain at least one numeric character." : "პაროლი უნდა მოიცავდეს ერთ ციფრს მაინც.",
    "Password need to contain at least one special character." : "პაროლი უნდა მოიცავდეს ერთ სპეციალურ ნიშანს მაინც.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "პაროლი ერთ-ერთია 1000000 ყველაზე ჩვეულებრივებიდან. გთხოვთ გახადოთ ის უნიკალური."
},
"nplurals=1; plural=0;");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/ka_GE.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "პაროლი %s ნიშნის მქონე მაინც უნდა იყოს",
    "Password needs to contain at least one lower and one upper case character." : "პაროლი საჭიროებს ერთ დიდ და ერთ პატარა ასოს მაინც.",
    "Password needs to contain at least one numeric character." : "პაროლი უნდა მოიცავდეს ერთ ციფრს მაინც.",
    "Password needs to contain at least one special character." : "პაროლი უნდა მოიცავდეს ერთ სპეციალურ ნიშანს მაინც.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "პაროლი ერთ-ერთია 1000000 ყველაზე ჩვეულებრივებიდან. გთხოვთ გახადოთ ის უნიკალური.",
    "Password is present in compromised password list. Please choose a different password." : "პაროლი არსებობს კომპრომეტირებული პაროლების სიაში. გთხოვთ აირჩიოთ სხვა პაროლი.",
    "Password policy" : "პაროლის პოლიტიკა",
    "Minimal length" : "მინ. სიგრძე",
    "Forbid common passwords" : "აკრძალეთ ერთნაირი პაროლები",
    "Enforce upper and lower case characters" : "შემოიღეთ დიდი და პატარა ასოები",
    "Enforce numeric characters" : "შემოიღეთ ნუმერიკული ნიშნები",
    "Enforce special characters" : "შემოიღეთ სპეციალური ნიშნები",
    "Password need to be at least %s characters long" : "პაროლი უნდა იყოს %sნიშნის მქონე მაინც",
    "Password need to contain at least one lower case character and one upper case character." : "პაროლი საჭიროებს ერთ დიდ და ერთ პატარა ასოს მაინც.",
    "Password need to contain at least one numeric character." : "პაროლი უნდა მოიცავდეს ერთ ციფრს მაინც.",
    "Password need to contain at least one special character." : "პაროლი უნდა მოიცავდეს ერთ სპეციალურ ნიშანს მაინც.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "პაროლი ერთ-ერთია 1000000 ყველაზე ჩვეულებრივებიდან. გთხოვთ გახადოთ ის უნიკალური.",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "შეამოწმეთ დარღვეულია თუ არა პაროლი haveibeenpwned.com მისამართზე"
},
"nplurals=2; plural=(n!=1);");
